@@ -28,13 +28,13 @@ impl From<bind::SDL_GameControllerButtonBind> for MapInput {
     fn from(raw: bind::SDL_GameControllerButtonBind) -> Self {
         use MapInput::*;
         match raw.bindType {
-            bind::SDL_GameControllerBindType_SDL_CONTROLLER_BINDTYPE_BUTTON => Button {
+            bind::SDL_CONTROLLER_BINDTYPE_BUTTON => Button {
                 index: unsafe { raw.value.button } as u32,
             },
-            bind::SDL_GameControllerBindType_SDL_CONTROLLER_BINDTYPE_AXIS => Axis {
+            bind::SDL_CONTROLLER_BINDTYPE_AXIS => Axis {
                 index: unsafe { raw.value.axis } as u32,
             },
-            bind::SDL_GameControllerBindType_SDL_CONTROLLER_BINDTYPE_HAT => Hat {
+            bind::SDL_CONTROLLER_BINDTYPE_HAT => Hat {
                 index: unsafe { raw.value.hat.hat } as u32,
                 mask: unsafe { raw.value.hat.hat_mask } as u32,
             },
